@@ -1,7 +1,10 @@
 import threading
 from threading import (_active_limbo_lock, _limbo, _active, _sys, _trace_hook,
                        _profile_hook, _format_exc)
-import warnings
+try:
+    import zmq     # NOQA
+except ImportError:
+    zmq = None     # NOQA
 
 
 # see http://bugs.python.org/issue1596321
@@ -78,42 +81,3 @@ threading.Thread._Thread__bootstrap_inner = _bootstrap_inner
 threading.Thread._Thread__delete = _delete
 threading.Thread._Thread__stop_old = threading.Thread._Thread__stop
 threading.Thread._Thread__stop = _stop
-
-#
-# zmq patching
-#
-_MSG = """\
-We have detected that you have gevent in your
-environment. In order to have Circus working, you *must*
-install PyZMQ >= 2.2.0.1.
-"""
-
-USING_GEVENT = False
-
-try:
-    import gevent                   # NOQA
-    from gevent import monkey       # NOQA
-    try:
-        import zmq.eventloop as old_io
-        import zmq.green as zmq         # NOQA
-        old_io.ioloop.Poller = zmq.Poller
-    except ImportError:
-        # older version
-        import zmq
-        try:
-            from gevent_zeromq import (  # NOQA
-                monkey_patch, IOLOOP_IS_MONKEYPATCHED)
-            monkey_patch()
-            warnings.warn("gevent_zeromq is deprecated, please "
-                          "use PyZMQ >= 2.2.0.1")
-        except ImportError:
-            raise ImportError(_MSG)
-
-    monkey.patch_all()
-    USING_GEVENT = True
-except ImportError:
-    try:
-        import zmq      # NOQA
-    except ImportError:
-        # lazy loading
-        zmq = None      # NOQA
