@@ -303,7 +303,8 @@ def parse_arguments(args, commands):
 
     options = {
         'endpoint': {'default': None, 'help': 'connection endpoint'},
-        'timeout': {'default': 5, 'help': 'connection timeout'},
+        'timeout': {'default': 5, 'help': 'connection timeout',
+                    'type': int},
 
         'help': {
             'default': False,
