@@ -90,8 +90,8 @@ class Command(object):
             raise MessageError("program %s not found" % watcher_name)
 
     def _get_signal(self, sig):
-        if sig.lower() in ('quit', 'hup', 'kill', 'term', 'ttin',
-                'ttou', 'usr1', 'usr2'):
+        if sig.lower() in ('quit', 'hup', 'kill', 'term', 'ttin', 'ttou',
+                           'usr1', 'usr2'):
             return getattr(signal, "SIG%s" % sig.upper())
         elif sig.isdigit():
             return int(sig)
@@ -103,7 +103,6 @@ class Command(object):
 
         for propname in self.properties:
             if propname not in props:
-                raise MessageError("message invalid %r is missing" %
-                        propname)
+                raise MessageError("message invalid %r is missing" % propname)
 
 Command = CommandMeta('Command', (Command,), {})
