@@ -38,7 +38,6 @@ class Controller(object):
         self.ctrl_socket = self.context.socket(zmq.ROUTER)
         self.ctrl_socket.bind(self.endpoint)
         self.ctrl_socket.linger = 0
-
         self.stream = zmqstream.ZMQStream(self.ctrl_socket, self.loop)
         self.stream.on_recv(self.handle_message)
 
@@ -50,6 +49,8 @@ class Controller(object):
 
     def stop(self):
         self.caller.stop()
+        self.stream.flush()
+        self.stream.close()
         self.ctrl_socket.close()
 
     def wakeup(self):
@@ -93,8 +94,8 @@ class Controller(object):
         try:
             cmd = self.commands[cmd_name.lower()]
         except KeyError:
-            error = "unknown command: %r" % cmd_name
-            return self.send_error(cid, msg, error, cast=cast,
+            error_ = "unknown command: %r" % cmd_name
+            return self.send_error(cid, msg, error_, cast=cast,
                                    errno=errors.UNKNOWN_COMMAND)
 
         try:
