@@ -22,7 +22,6 @@ class StatsClient(CircusConsumer):
     def iter_messages(self):
         """ Yields tuples of (watcher, subtopic, stat)"""
         recv = self.pubsub_socket.recv_multipart
-
         with self:
             while True:
                 try:
@@ -32,7 +31,6 @@ class StatsClient(CircusConsumer):
                         continue
 
                 if len(events) == 0:
-                    print 'nothing'
                     continue
 
                 try:
@@ -161,8 +159,9 @@ def _paint(stdscr, watchers=None, old_h=None, old_w=None):
                 line += 1
             line += 1
 
-    if line <= current_h and len(watchers) > 0:
+    if line < current_h and len(watchers) > 0:
         stdscr.addstr(line, 0, '-' * current_w)
+
     stdscr.refresh()
     return current_h, current_w
 
