@@ -84,6 +84,9 @@ class TestUtil(unittest.TestCase):
     def test_replace_gnu_args(self):
         repl = replace_gnu_args
 
+        self.assertEquals('dont change --fd ((circus.me)) please',
+                          repl('dont change --fd ((circus.me)) please'))
+
         self.assertEquals('dont change --fd $(circus.me) please',
                           repl('dont change --fd $(circus.me) please'))
 
@@ -98,18 +101,34 @@ class TestUtil(unittest.TestCase):
         self.assertEquals('foo, foobar, baz',
                           replace_gnu_args('foo, $(circus.test), baz',
                                            test='foobar'))
+        self.assertEquals('foo, foobar, baz',
+                          replace_gnu_args('foo, ((circus.test)), baz',
+                                           test='foobar'))
 
         self.assertEquals('foobar', replace_gnu_args('$(cir.test)',
                                                      prefix='cir',
                                                      test='foobar'))
+
+        self.assertEquals('foobar', replace_gnu_args('((cir.test))',
+                                                     prefix='cir',
+                                                     test='foobar'))
+
         self.assertEquals('thats an int 2',
                           repl('thats an int $(s.me)', prefix='s',
                           me=2))
 
+        self.assertEquals('thats an int 2',
+                          repl('thats an int ((s.me))', prefix='s',
+                          me=2))
+
         self.assertEquals('thats an int 2',
                           repl('thats an int $(me)', prefix=None,
                           me=2))
 
+        self.assertEquals('thats an int 2',
+                          repl('thats an int ((me))', prefix=None,
+                          me=2))
+
     def test_strict_parser(self):
         cp = StrictConfigParser()
         bad_ini = os.path.join(os.path.dirname(__file__), 'bad.ini')
