@@ -8,6 +8,7 @@ from random import randint
 
 from psutil import NoSuchProcess
 from zmq.utils.jsonapi import jsonmod as json
+from zmq.eventloop import ioloop
 
 from circus.process import Process, DEAD_OR_ZOMBIE, UNEXISTING
 from circus import logger
@@ -104,10 +105,6 @@ class Watcher(object):
       - **name** - the stream name (*stderr* or *stdout*)
       - **data** - the data
 
-    - **stream_backend** -- the backend that will be used for the streaming
-      process. Can be *thread* or *gevent*. When set to *gevent* you need
-      to have *gevent* and *gevent_zmq* installed. (default: thread)
-
     - **priority** -- integer that defines a priority for the watcher. When
       the Arbiter do some operations on all watchers, it will sort them
       with this field, from the bigger number to the smallest.
@@ -120,6 +117,10 @@ class Watcher(object):
       descriptors, thus can reuse the sockets opened by circusd.
       (default: False)
 
+    - **on_demand** -- If True, the processes will be started only
+      at the first connection to the socket
+      (default: False)
+
     - **copy_env** -- If True, the environment in which circus is running
       run will be reproduced for the workers. (default: False)
 
@@ -150,18 +151,23 @@ class Watcher(object):
 
     - **respawn** -- If set to False, the processes handled by a watcher will
       not be respawned automatically. (default: True)
+
+    - **virtualenv** -- The root directory of a virtualenv. If provided, the
+      watcher will load the environment for its execution. (default: None)
     """
     def __init__(self, name, cmd, args=None, numprocesses=1, warmup_delay=0.,
                  working_dir=None, shell=False, uid=None, max_retry=5,
                  gid=None, send_hup=False, env=None, stopped=True,
                  graceful_timeout=30., prereload_fn=None,
                  rlimits=None, executable=None, stdout_stream=None,
-                 stderr_stream=None, stream_backend='thread', priority=0,
+                 stderr_stream=None, priority=0, loop=None,
                  singleton=False, use_sockets=False, copy_env=False,
                  copy_path=False, max_age=0, max_age_variance=30,
-                 hooks=None, respawn=True, **options):
+                 hooks=None, respawn=True, autostart=True, on_demand=False,
+                 virtualenv=None, **options):
         self.name = name
         self.use_sockets = use_sockets
+        self.on_demand = on_demand
         self.res_name = name.lower().replace(" ", "_")
         self.numprocesses = int(numprocesses)
         self.warmup_delay = warmup_delay
@@ -172,7 +178,6 @@ class Watcher(object):
         self.graceful_timeout = float(graceful_timeout)
         self.prereload_fn = prereload_fn
         self.executable = None
-        self.stream_backend = stream_backend
         self.priority = priority
         self.stdout_stream_conf = copy.copy(stdout_stream)
         self.stderr_stream_conf = copy.copy(stderr_stream)
@@ -184,11 +189,14 @@ class Watcher(object):
         self.singleton = singleton
         self.copy_env = copy_env
         self.copy_path = copy_path
+        self.virtualenv = virtualenv
         self.max_age = int(max_age)
         self.max_age_variance = int(max_age_variance)
         self.ignore_hook_failure = ['before_stop', 'after_stop']
         self.hooks = self._resolve_hooks(hooks)
         self.respawn = respawn
+        self.autostart = autostart
+        self.loop = loop or ioloop.IOLoop.instance()
 
         if singleton and self.numprocesses not in (0, 1):
             raise ValueError("Cannot have %d processes with a singleton "
@@ -198,7 +206,7 @@ class Watcher(object):
                           "uid", "gid", "send_hup", "shell", "env",
                           "max_retry", "cmd", "args", "graceful_timeout",
                           "executable", "use_sockets", "priority", "copy_env",
-                          "singleton", "stdout_stream_conf",
+                          "singleton", "stdout_stream_conf", "on_demand",
                           "stderr_stream_conf", "max_age", "max_age_variance")
                          + tuple(options.keys()))
 
@@ -225,6 +233,9 @@ class Watcher(object):
                                   'same value'))
             self.env = env
 
+        if self.virtualenv:
+            util.load_virtualenv(self)
+
         self.rlimits = rlimits
         self.send_hup = send_hup
         self.sockets = self.evpub_socket = None
@@ -236,7 +247,7 @@ class Watcher(object):
                     self.stdout_redirector.running):
                 self.stdout_redirector.kill()
             self.stdout_redirector = get_pipe_redirector(
-                self.stdout_stream, backend=self.stream_backend)
+                self.stdout_stream, loop=self.loop)
         else:
             self.stdout_redirector = None
 
@@ -246,7 +257,7 @@ class Watcher(object):
                 self.stderr_redirector.kill()
 
             self.stderr_redirector = get_pipe_redirector(
-                self.stderr_stream, backend=self.stream_backend)
+                self.stderr_stream, loop=self.loop)
         else:
             self.stderr_redirector = None
 
@@ -274,9 +285,10 @@ class Watcher(object):
         return resolved_hooks
 
     @classmethod
-    def load_from_config(cls, config):
+    def load_from_config(cls, config, **extras):
         if 'env' in config:
             config['env'] = parse_env_dict(config['env'])
+        config.update(extras)
         return cls(name=config.pop('name'), cmd=config.pop('cmd'), **config)
 
     @util.debuglog
@@ -396,6 +408,11 @@ class Watcher(object):
     def spawn_processes(self):
         """Spawn processes.
         """
+        # when an on_demand process dies, do not restart it until
+        # the next event
+        if self.on_demand and not self.arbiter.socket_event:
+            self.stopped = True
+            return
         for i in range(self.numprocesses - len(self.processes)):
             self.spawn_process()
             time.sleep(self.warmup_delay)
@@ -418,7 +435,7 @@ class Watcher(object):
         cmd = util.replace_gnu_args(self.cmd, sockets=self._get_sockets_fds())
         self._process_counter += 1
         nb_tries = 0
-        while nb_tries < self.max_retry:
+        while nb_tries < self.max_retry or self.max_retry == -1:
             process = None
             try:
                 process = Process(self._process_counter, cmd,
@@ -552,7 +569,6 @@ class Watcher(object):
         """Stop.
         """
         logger.debug('stopping the %s watcher' % self.name)
-
         # stop redirectors
         if self.stdout_redirector is not None:
             self.stdout_redirector.kill()
@@ -570,10 +586,6 @@ class Watcher(object):
 
         while self.get_active_processes() and time.time() < limit:
             self.kill_processes(signal.SIGTERM)
-            try:
-                time.sleep(0.1)
-            except KeyboardInterrupt:
-                pass
             self.reap_processes()
 
         self.kill_processes(signal.SIGKILL)
@@ -626,6 +638,9 @@ class Watcher(object):
         if not self.stopped:
             return
 
+        if self.on_demand and not self.arbiter.socket_event:
+            return
+
         self.stopped = False
 
         if not self.call_hook('before_start'):
